@@ -34,13 +34,13 @@ public:
     uint currentUser();
     QString currentUserUuid();
     bool setCurrentUser(uint uid);
-    bool setNextSessionUser(uint uid);
     bool modifyUser(uint uid, const QString &newFullName);
 
     QString userUuid(uint uid);
     QStringList usersGroups(uint uid);
     bool addToGroups(uint uid, const QStringList &groups);
     bool removeFromGroups(uint uid, const QStringList &groups);
+    bool enableGuestUser(bool enable);
 
 private:
     QDBusInterface *m_iface;
